Event

Enum Event 

pub enum Event<C, M, S> {
    Cmd(C),
    Msg {
        from: NodeId,
        msg: M,
    },
    Timer(TimerId),
    ScopeEvent(S),
    Init,
    Recovery,
}
An event a protocol can be given. Used by drivers and by the test helper.

Variants



Cmd(C)



Msg

Fields

from: NodeId
msg: M


Timer(TimerId)

A timer registered by this protocol, or by something it composes, has fired.



ScopeEvent(S)

A scope this protocol’s guarantees depended on has ended.



Init

This process is starting for the first time, with nothing written down.



Recovery

This process restarted, and something it wrote down survived.